@@ -2,7 +2,7 @@ use std::ops::{Deref, DerefMut};
 
 use rustc_hash::FxHashMap;
 use swc_atoms::JsWord;
-use swc_common::Span;
+use swc_common::{Span, SyntaxContext};
 use swc_ecma_ast::*;
 use swc_ecma_utils::{ident::IdentLike, prop_name_eq, ExprExt, Id};
 use swc_ecma_visit::{noop_visit_mut_type, VisitMut, VisitMutWith};
@@ -168,23 +168,36 @@ pub(crate) fn is_valid_for_lhs(e: &Expr) -> bool {
     !matches!(e, Expr::Lit(..) | Expr::Unary(..))
 }
 
-pub(crate) struct MultiReplacer {
-    pub vars: FxHashMap<Id, Box<Expr>>,
-    pub changed: bool,
-    pub clone: bool,
+/// Variable remapper
+///
+/// - Used for evaluating IIFEs
+
+pub(crate) struct Remapper {
+    pub vars: FxHashMap<Id, SyntaxContext>,
 }
 
-impl MultiReplacer {
-    fn var(&mut self, i: &Id) -> Option<Box<Expr>> {
-        if self.clone {
-            self.vars.get(i).cloned()
-        } else {
-            self.vars.remove(i)
+impl VisitMut for Remapper {
+    noop_visit_mut_type!();
+
+    fn visit_mut_ident(&mut self, i: &mut Ident) {
+        if let Some(new_ctxt) = self.vars.get(&i.to_id()).copied() {
+            i.span.ctxt = new_ctxt;
         }
     }
 }
 
-impl VisitMut for MultiReplacer {
+pub(crate) struct MultiReplacer<'a> {
+    pub vars: &'a mut FxHashMap<Id, Box<Expr>>,
+    pub changed: bool,
+}
+
+impl MultiReplacer<'_> {
+    fn var(&mut self, i: &Id) -> Option<Box<Expr>> {
+        self.vars.remove(i)
+    }
+}
+
+impl VisitMut for MultiReplacer<'_> {
     noop_visit_mut_type!();
 
     fn visit_mut_expr(&mut self, e: &mut Expr) {
